[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]

[tor-commits] [tor/master] subsysmgr: use IDX_NONE is an exception value, not -1.



commit 3afbb29bee060b191e10aaec134a819047c3cf5e
Author: Nick Mathewson <nickm@xxxxxxxxxxxxxx>
Date:   Tue Nov 5 10:24:34 2019 -0500

    subsysmgr: use IDX_NONE is an exception value, not -1.
---
 src/app/main/subsysmgr.c | 12 ++++++++----
 1 file changed, 8 insertions(+), 4 deletions(-)

diff --git a/src/app/main/subsysmgr.c b/src/app/main/subsysmgr.c
index 4189519ca..8be4a7d75 100644
--- a/src/app/main/subsysmgr.c
+++ b/src/app/main/subsysmgr.c
@@ -33,15 +33,19 @@
  **/
 static bool subsystem_array_validated = false;
 
+/** Index value indicating that a subsystem has no options/state object, and
+ * so that object does not have an index. */
+#define IDX_NONE (-1)
+
 /**
  * Runtime status of a single subsystem.
  **/
 typedef struct subsys_status_t {
   /** True if the given subsystem is initialized. */
   bool initialized;
   /** Index for this subsystem's options object, or -1 for none. */
   int options_idx;
   /** Index for this subsystem's state object, or -1 for none. */
   int state_idx;
 } subsys_status_t;
 
@@ -62,8 +66,8 @@ subsys_status_clear(subsys_status_t *status)
     return;
   memset(status, 0, sizeof(*status));
   status->initialized = false;
-  status->state_idx = -1;
-  status->options_idx = -1;
+  status->state_idx = IDX_NONE;
+  status->options_idx = IDX_NONE;
 }
 
 /**
@@ -33,15 +33,19 @@
   /** True if the given subsystem is initialized. */
   bool initialized;
-  /** Index for this subsystem's options object, or -1 for none. */
+  /** Index for this subsystem's options object, or IDX_NONE for none. */
   int options_idx;
@@ -33,15 +33,19 @@
   int options_idx;
-  /** Index for this subsystem's state object, or -1 for none. */
+  /** Index for this subsystem's state object, or IDX_NONE for none. */
   int state_idx;
 } subsys_status_t;



_______________________________________________
tor-commits mailing list
tor-commits@xxxxxxxxxxxxxxxxxxxx
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits